@@ -32,6 +32,11 @@ from adafruit_ble.uuid import StandardUUID
 from adafruit_ble.characteristics import Characteristic, ComplexCharacteristic
 from adafruit_ble.characteristics.int import Uint8Characteristic
 
+try:
+    from typing import Optional
+except ImportError:
+    pass
+
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BLE_Heart_Rate.git"
 
@@ -73,10 +78,10 @@ class _HeartRateMeasurement(ComplexCharacteristic):
 
     uuid = StandardUUID(0x2A37)
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(properties=Characteristic.NOTIFY)
 
-    def bind(self, service):
+    def bind(self, service: "HeartRateService") -> _bleio.PacketBuffer:
         """Bind to a HeartRateService."""
         bound_characteristic = super().bind(service)
         bound_characteristic.set_cccd(notify=True)
@@ -120,13 +125,13 @@ class HeartRateService(Service):
 
     _BODY_LOCATIONS = ("Other", "Chest", "Wrist", "Finger", "Hand", "Ear Lobe", "Foot")
 
-    def __init__(self, service=None):
+    def __init__(self, service: Optional["HeartRateService"] = None) -> None:
         super().__init__(service=service)
         # Defer creating buffer until needed.
         self._measurement_buf = None
 
     @property
-    def measurement_values(self):
+    def measurement_values(self) -> Optional[_HeartRateMeasurement]:
         """All the measurement values, returned as a HeartRateMeasurementValues
         namedtuple.
 
@@ -174,7 +179,7 @@ class HeartRateService(Service):
         return HeartRateMeasurementValues(bpm, contact, energy_expended, rr_values)
 
     @property
-    def location(self):
+    def location(self) -> str:
         """The location of the sensor on the human body, as a string.
 
         Note that the specification describes a limited number of locations.
